@@ -26,9 +26,16 @@
 #include <librsvg/rsvg-cairo.h>
 #include <math.h>
 #include <cityinfo.h>
-
+#include <mce/mode-names.h>
+#include <mce/dbus-names.h>
+#include <dbus/dbus-glib-lowlevel.h>
 #include "desktop-clock-widget.h"
 
+#define MCE_SIGNAL_MATCH "type='signal'," \
+        "sender='"    MCE_SERVICE     "'," \
+        "path='"      MCE_SIGNAL_PATH "'," \
+        "interface='" MCE_SIGNAL_IF   "'"
+
 #define HD_APP_MGR_DBUS_NAME "com.nokia.HildonDesktop.AppMgr"
 #define HD_APP_MGR_DBUS_PATH "/com/nokia/HildonDesktop/AppMgr"
 #define HD_APP_MGR_DBUS_IFACE "com.nokia.HildonDesktop.AppMgr"
@@ -45,6 +52,7 @@
 #define DESKTOP_CLOCK_WIDGET_CONFIG_KEY_SHOW_CITYNAME "show_cityname"
 #define DESKTOP_CLOCK_WIDGET_CONFIG_KEY_TWENTY_FOUR_HOURS "twenty_four_hours"
 #define DESKTOP_CLOCK_WIDGET_CONFIG_KEY_CUSTOM_THEME_NAME "custom_theme_name"
+#define DESKTOP_CLOCK_WIDGET_CONFIG_KEY_AUTOROTATE "autorotate"
 
 #define CLOCK_DROP_SHADOW_SVG "clock-drop-shadow.svg"
 #define CLOCK_FACE_SHADOW_SVG "clock-face-shadow.svg"
@@ -61,6 +69,11 @@
 
 #define DESKTOP_CLOCK_WIDGET_BUILTIN_THEME "/usr/share/pixmaps/desktop-clock-widget/"
 
+#define LANDSCAPE 0
+#define PORTRAIT 1
+#define LANDSCAPE_INV 2
+#define PORTRAIT_INV 3
+
 HD_DEFINE_PLUGIN_MODULE (DesktopClockWidgetHomePlugin, desktop_clock_widget_home_plugin, HD_TYPE_HOME_PLUGIN_ITEM)
 
 #define DESKTOP_CLOCK_WIDGET_HOME_PLUGIN_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE(obj, \
@@ -107,6 +120,8 @@ struct _DesktopClockWidgetHomePluginPrivate
   RsvgHandle* second_shadow_svg_handle;
   Cityinfo* city_info;
   guint time_out_handler;
+  gboolean autorotate;
+  guint orientation_mode;
 };
 
 // to prevent unloading the module, as
@@ -400,6 +415,14 @@ desktop_clock_widget_read_settings(DesktopClockWidgetHomePlugin* desktop_plugin)
 								      desktop_plugin->priv->iD, 
 								      DESKTOP_CLOCK_WIDGET_CONFIG_KEY_CUSTOM_THEME_NAME, 
 								      NULL);
+    if(g_key_file_has_key(key_file, 
+			  desktop_plugin->priv->iD, 
+			  DESKTOP_CLOCK_WIDGET_CONFIG_KEY_AUTOROTATE, 
+			  NULL))
+      desktop_plugin->priv->autorotate = g_key_file_get_boolean(key_file, 
+				                 		desktop_plugin->priv->iD, 
+								DESKTOP_CLOCK_WIDGET_CONFIG_KEY_AUTOROTATE,
+								NULL);
     if(desktop_plugin->priv->city_info_id != CITYINFO_WRONG_ID)    
       desktop_plugin->priv->city_info = cityinfo_from_id(desktop_plugin->priv->city_info_id);
   }
@@ -470,6 +493,10 @@ desktop_clock_widget_write_settings(DesktopClockWidgetHomePlugin* desktop_plugin
 			 desktop_plugin->priv->iD, 
 			 DESKTOP_CLOCK_WIDGET_CONFIG_KEY_ZONE_ID, 
 			 desktop_plugin->priv->city_info_id);
+  g_key_file_set_boolean(key_file, 
+			 desktop_plugin->priv->iD, 
+			 DESKTOP_CLOCK_WIDGET_CONFIG_KEY_AUTOROTATE,
+			 desktop_plugin->priv->autorotate);
   if(desktop_plugin->priv->custom_theme_name!=NULL)
   {
     g_key_file_set_string(key_file, 
@@ -824,6 +851,160 @@ desktop_clock_widget_save_custom_theme(gchar* theme_path, DesktopClockWidgetHome
   g_object_unref(parent);
 }
 
+static void
+_increment_slider(GtkButton* button, gpointer user_data)
+{
+  GtkRange* range = GTK_RANGE(user_data);
+  gtk_range_set_value(range, gtk_range_get_value(range) + 1);
+}
+
+static void
+_decrement_slider(GtkButton* button, gpointer user_data)
+{
+  GtkRange* range = GTK_RANGE(user_data);
+  gtk_range_set_value(range, gtk_range_get_value(range) - 1);
+}
+
+static DBusHandlerResult
+_handle_dbus_filter_func(DBusConnection * connection,
+			 DBusMessage * message, 
+			 void* user_data)
+{
+  DesktopClockWidgetHomePlugin* desktop_plugin = DESKTOP_CLOCK_WIDGET_HOME_PLUGIN(user_data);
+  DBusMessageIter iter;
+  const gchar* mode = NULL;
+  if(dbus_message_is_signal(message, MCE_SIGNAL_IF, MCE_DEVICE_ORIENTATION_SIG))
+  {
+    if(dbus_message_iter_init(message, &iter))
+    {
+      int height = desktop_plugin->priv->clock_height;
+      if(desktop_plugin->priv->show_cityname)
+	height += 16;
+      dbus_message_iter_get_basic(&iter, &mode);
+      if(strcmp(mode, MCE_ORIENTATION_PORTRAIT) == 0)
+      {
+	desktop_plugin->priv->orientation_mode = PORTRAIT;
+	gtk_widget_set_size_request(GTK_WIDGET(desktop_plugin), 
+				    height,
+				    desktop_plugin->priv->clock_width);
+	gtk_window_resize(GTK_WINDOW(desktop_plugin),
+			  height,
+			  desktop_plugin->priv->clock_width);
+      }
+      else if(strcmp(mode, MCE_ORIENTATION_LANDSCAPE) == 0)
+      {
+	desktop_plugin->priv->orientation_mode = LANDSCAPE;
+	gtk_widget_set_size_request(GTK_WIDGET(desktop_plugin), 
+				    desktop_plugin->priv->clock_width,
+				    height);
+	gtk_window_resize(GTK_WINDOW(desktop_plugin),
+			  desktop_plugin->priv->clock_width,
+			  height);
+      }
+      else if(strcmp(mode, MCE_ORIENTATION_PORTRAIT_INVERTED) == 0)
+      {
+	desktop_plugin->priv->orientation_mode = PORTRAIT_INV;
+	gtk_widget_set_size_request(GTK_WIDGET(desktop_plugin), 
+				    height,
+				    desktop_plugin->priv->clock_width);
+	gtk_window_resize(GTK_WINDOW(desktop_plugin),
+			  height,
+			  desktop_plugin->priv->clock_width);
+      }
+      else if(strcmp(mode, MCE_ORIENTATION_LANDSCAPE_INVERTED) == 0)
+      {
+	desktop_plugin->priv->orientation_mode = LANDSCAPE_INV;
+	gtk_widget_set_size_request(GTK_WIDGET(desktop_plugin), 
+				    desktop_plugin->priv->clock_width,
+				    height);
+	gtk_window_resize(GTK_WINDOW(desktop_plugin),
+			  desktop_plugin->priv->clock_width,
+			  height);
+
+      }
+      gtk_widget_queue_draw(GTK_WIDGET(desktop_plugin));
+    }
+  }
+  return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+}
+
+
+static void
+_enable_listen_for_device_orientation(DesktopClockWidgetHomePlugin* desktop_plugin)
+{
+  DBusGConnection* dbus_g_conn = hd_home_plugin_item_get_dbus_g_connection(&desktop_plugin->hitem, 
+									 DBUS_BUS_SYSTEM,
+									 NULL);
+  DBusGProxy* dbus_proxy = dbus_g_proxy_new_for_name(dbus_g_conn,
+						     MCE_SERVICE,
+						     MCE_REQUEST_PATH,
+						     MCE_REQUEST_IF);
+  if(dbus_proxy)
+  {
+    dbus_g_proxy_call_no_reply(dbus_proxy,
+			       MCE_ACCELEROMETER_ENABLE_REQ, 
+			       G_TYPE_INVALID,
+			       G_TYPE_STRING,
+			       G_TYPE_STRING,
+			       G_TYPE_STRING,
+			       G_TYPE_INT,
+			       G_TYPE_INT,
+			       G_TYPE_INT,
+			       G_TYPE_INVALID);
+    
+    g_object_unref(dbus_proxy);
+  }
+
+  if(dbus_g_conn)
+  {
+    DBusConnection* dbus_conn = dbus_g_connection_get_connection(dbus_g_conn);
+    dbus_bus_add_match(dbus_conn, MCE_SIGNAL_MATCH, NULL);
+    dbus_connection_add_filter(dbus_conn, (DBusHandleMessageFunction)_handle_dbus_filter_func, desktop_plugin, NULL);
+  }
+  else
+  {
+    g_warning("cann not connect to system bus\n");
+  }
+}
+static void
+_disable_listen_for_device_orientation(DesktopClockWidgetHomePlugin* desktop_plugin)
+{
+  DBusGConnection* dbus_g_conn = hd_home_plugin_item_get_dbus_g_connection(&desktop_plugin->hitem, 
+									 DBUS_BUS_SYSTEM,
+									 NULL);
+  DBusGProxy* dbus_proxy = dbus_g_proxy_new_for_name(dbus_g_conn,
+						     MCE_SERVICE,
+						     MCE_REQUEST_PATH,
+						     MCE_REQUEST_IF);
+  if(dbus_proxy)
+  {/*
+    dbus_g_proxy_call_no_reply(dbus_proxy,
+			       MCE_ACCELEROMETER_DISABLE_REQ, 
+			       G_TYPE_INVALID,
+			       G_TYPE_STRING,
+			       G_TYPE_STRING,
+			       G_TYPE_STRING,
+			       G_TYPE_INT,
+			       G_TYPE_INT,
+			       G_TYPE_INT,
+			       G_TYPE_INVALID);
+   */ 
+    g_object_unref(dbus_proxy);
+  }
+
+  if(dbus_g_conn)
+  {
+    DBusConnection* dbus_conn = dbus_g_connection_get_connection(dbus_g_conn);
+    dbus_bus_remove_match(dbus_conn, MCE_SIGNAL_MATCH, NULL);
+    dbus_connection_remove_filter(dbus_conn, (DBusHandleMessageFunction)_handle_dbus_filter_func, desktop_plugin);
+  }
+  else
+  {
+    g_warning("cann not connect to system bus\n");
+  }
+}
+
+
 static void
 desktop_clock_widget_show_settings_dialog(GtkWidget* widget, gpointer data)
 {
@@ -839,6 +1020,7 @@ desktop_clock_widget_show_settings_dialog(GtkWidget* widget, gpointer data)
   GtkWidget* clock_height_slider;
   GtkWidget* stock_theme_checkbutton;
   GtkWidget* custom_theme_selection_button;
+  GtkWidget* autorotate_checkbutton;
 
   timezone_list = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
   desktop_clock_widget_init_clock_list(timezone_list);
@@ -878,11 +1060,18 @@ desktop_clock_widget_show_settings_dialog(GtkWidget* widget, gpointer data)
   gtk_button_set_label(GTK_BUTTON(show_cityname_checkbutton),
 		       "Display Name");
 
+  autorotate_checkbutton = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(autorotate_checkbutton),
+				 desktop_plugin->priv->autorotate);
+  gtk_button_set_label(GTK_BUTTON(autorotate_checkbutton),
+		       "autorotate");
+
   clock_width_slider = hildon_gtk_hscale_new();
   gtk_adjustment_configure(gtk_range_get_adjustment(GTK_RANGE(clock_width_slider)),
 			   desktop_plugin->priv->clock_width,
 			   32, 351,
 			   1, 1, 1);
+
   gtk_scale_set_value_pos(GTK_SCALE(clock_width_slider), GTK_POS_RIGHT);
   gtk_scale_set_draw_value(GTK_SCALE(clock_width_slider), TRUE);
   gtk_scale_set_digits(GTK_SCALE(clock_width_slider), 0);
@@ -895,6 +1084,20 @@ desktop_clock_widget_show_settings_dialog(GtkWidget* widget, gpointer data)
   gtk_scale_set_draw_value(GTK_SCALE(clock_height_slider), TRUE);
   gtk_scale_set_digits(GTK_SCALE(clock_height_slider), 0);
 
+  GtkWidget* decrement_width_button = hildon_gtk_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  gtk_button_set_label(GTK_BUTTON(decrement_width_button), "-");
+  GtkWidget* increment_width_button = hildon_gtk_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  gtk_button_set_label(GTK_BUTTON(increment_width_button), "+");
+  GtkWidget* decrement_height_button = hildon_gtk_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  gtk_button_set_label(GTK_BUTTON(decrement_height_button), "-");
+  GtkWidget* increment_height_button = hildon_gtk_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  gtk_button_set_label(GTK_BUTTON(increment_height_button), "+");
+
+  g_signal_connect(decrement_width_button, "clicked", G_CALLBACK(_decrement_slider), clock_width_slider);
+  g_signal_connect(increment_width_button, "clicked", G_CALLBACK(_increment_slider), clock_width_slider);
+  g_signal_connect(decrement_height_button, "clicked", G_CALLBACK(_decrement_slider), clock_height_slider);
+  g_signal_connect(increment_height_button, "clicked", G_CALLBACK(_increment_slider), clock_height_slider);
+
   stock_theme_checkbutton = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
   gtk_button_set_label(GTK_BUTTON(stock_theme_checkbutton),
 		       "Built-in Theme");
@@ -921,6 +1124,7 @@ desktop_clock_widget_show_settings_dialog(GtkWidget* widget, gpointer data)
 				       dgettext("hildon-libs", "wdgt_bd_done"),
 				       GTK_RESPONSE_OK,
 				       NULL);
+  gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 325);
   GtkWidget* box1 = gtk_hbox_new(TRUE, 3);
   gtk_box_pack_start(GTK_BOX(box1), show_seconds_checkbutton, TRUE, TRUE, 1);
   gtk_box_pack_start(GTK_BOX(box1), twenty_four_hour_checkbutton, TRUE, TRUE, 1);
@@ -928,8 +1132,12 @@ desktop_clock_widget_show_settings_dialog(GtkWidget* widget, gpointer data)
   GtkWidget* box2 = gtk_hbox_new(FALSE, 3);
   GtkWidget* box2a = gtk_vbox_new(TRUE, 3);
   GtkWidget* box2b = gtk_vbox_new(TRUE, 3);
+  GtkWidget* box2c = gtk_vbox_new(TRUE, 3);
+  GtkWidget* box2d = gtk_vbox_new(TRUE, 3);
   GtkWidget* box3 = gtk_hbox_new(TRUE, 3);
   GtkWidget* box4 = gtk_hbox_new(TRUE, 3);
+  GtkWidget* box0 = gtk_hbox_new(TRUE, 3);
+
   gtk_box_pack_start(GTK_BOX(box3), stock_theme_checkbutton, TRUE, TRUE, 1);
   gtk_box_pack_start(GTK_BOX(box3), custom_theme_selection_button, TRUE, TRUE, 1);
 
@@ -939,20 +1147,36 @@ desktop_clock_widget_show_settings_dialog(GtkWidget* widget, gpointer data)
   gtk_box_pack_start(GTK_BOX(box2a), wlabel, TRUE, TRUE, 1);
   gtk_box_pack_start(GTK_BOX(box2a), hlabel, TRUE, TRUE, 1);
 
+  gtk_box_pack_start(GTK_BOX(box2c), decrement_width_button, FALSE, FALSE, 1);
+  gtk_box_pack_start(GTK_BOX(box2c), decrement_height_button, FALSE, FALSE, 1);
+
   gtk_box_pack_start(GTK_BOX(box2b), clock_width_slider, TRUE, TRUE, 1);
   gtk_box_pack_start(GTK_BOX(box2b), clock_height_slider, TRUE, TRUE, 1);
 
+  gtk_box_pack_start(GTK_BOX(box2d), increment_width_button, FALSE, FALSE, 1);
+  gtk_box_pack_start(GTK_BOX(box2d), increment_height_button, FALSE, FALSE, 1);
+
   gtk_box_pack_start(GTK_BOX(box2), box2a, FALSE, FALSE, 1);
+  gtk_box_pack_start(GTK_BOX(box2), box2c, FALSE, FALSE, 1);
   gtk_box_pack_start(GTK_BOX(box2), box2b, TRUE, TRUE, 1);
+  gtk_box_pack_start(GTK_BOX(box2), box2d, FALSE, FALSE, 1);
 
 
   gtk_box_pack_start(GTK_BOX(box4), show_cityname_checkbutton, TRUE, TRUE, 1);
   gtk_box_pack_start(GTK_BOX(box4), timezone_button, TRUE, TRUE, 1);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), box2, TRUE, TRUE, 1);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), box3, TRUE, TRUE, 1);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), box4, TRUE, TRUE, 1);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), box1, TRUE, TRUE, 1);
 
+  gtk_box_pack_start(GTK_BOX(box0), autorotate_checkbutton, TRUE, TRUE, 1);
+  GtkWidget* pan = hildon_pannable_area_new();
+  GtkWidget* vbox = gtk_vbox_new(FALSE, 0);
+  
+  gtk_box_pack_start(GTK_BOX(vbox), box2, TRUE, FALSE, 1);
+  gtk_box_pack_start(GTK_BOX(vbox), box3, TRUE, FALSE, 1);
+  gtk_box_pack_start(GTK_BOX(vbox), box4, TRUE, FALSE, 1);
+  gtk_box_pack_start(GTK_BOX(vbox), box1, TRUE, FALSE, 1);
+  gtk_box_pack_start(GTK_BOX(vbox), box0, TRUE, FALSE, 1);
+
+  hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pan), vbox);
+  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), pan, TRUE, TRUE, 0);
   gtk_widget_show_all(dialog);
 
   if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK)
@@ -974,6 +1198,19 @@ desktop_clock_widget_show_settings_dialog(GtkWidget* widget, gpointer data)
     desktop_plugin->priv->clock_height = new_height;
     desktop_plugin->priv->use_stock_theme = use_stock_theme;
     desktop_plugin->priv->show_cityname = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_cityname_checkbutton));
+    if(hildon_check_button_get_active(HILDON_CHECK_BUTTON(autorotate_checkbutton)) != desktop_plugin->priv->autorotate)
+      if(desktop_plugin->priv->autorotate)
+      {
+         desktop_plugin->priv->autorotate = FALSE;
+         _disable_listen_for_device_orientation(desktop_plugin);
+      }
+      else
+      {
+         desktop_plugin->priv->autorotate = TRUE;
+         _enable_listen_for_device_orientation(desktop_plugin); 
+      }
+
+    
     hildon_touch_selector_get_selected(HILDON_TOUCH_SELECTOR(selector),
 				       0, &iter);
     if(gtk_list_store_iter_is_valid(timezone_list, &iter))
@@ -1094,7 +1331,6 @@ desktop_clock_widget_open_clock_app(GtkWidget* widget, GdkEventButton* event, De
 						     HD_APP_MGR_DBUS_IFACE);
   if(dbus_proxy)
   {
-    
     dbus_g_proxy_call_no_reply(dbus_proxy,
 			       HD_APP_MGR_LAUNCH_APPLICATION,
 			       G_TYPE_STRING,
@@ -1107,6 +1343,48 @@ desktop_clock_widget_open_clock_app(GtkWidget* widget, GdkEventButton* event, De
   return FALSE;
 }
 
+static void
+_handle_orientation(cairo_t* cr, DesktopClockWidgetHomePlugin* desktop_plugin)
+{
+  if(desktop_plugin->priv->autorotate)
+  {
+    int clock_width = desktop_plugin->priv->clock_width;
+    int clock_height = desktop_plugin->priv->clock_height;
+    if(desktop_plugin->priv->orientation_mode == PORTRAIT)
+    {
+      if(desktop_plugin->priv->show_cityname)
+	clock_height +=16;
+      clock_width = desktop_plugin->priv->clock_height;
+      clock_height = desktop_plugin->priv->clock_width;
+      cairo_translate(cr, 
+	  0,
+	  clock_height);
+      cairo_rotate(cr, -M_PI/2.0);
+    }
+    else if(desktop_plugin->priv->orientation_mode == PORTRAIT_INV)
+    {
+
+      clock_width = desktop_plugin->priv->clock_height;
+      clock_height = desktop_plugin->priv->clock_width;
+      if(desktop_plugin->priv->show_cityname)
+	clock_width +=16;     
+      cairo_translate(cr, 
+	  clock_width,
+	  0);
+      cairo_rotate(cr, M_PI/2.0);
+    }
+    else if(desktop_plugin->priv->orientation_mode == LANDSCAPE_INV)
+    {
+      if(desktop_plugin->priv->show_cityname)
+	clock_height += 16;
+      cairo_translate(cr, 
+		      clock_width,
+		      clock_height);
+      cairo_rotate(cr, M_PI);
+    }
+  }
+}
+
 static gboolean
 desktop_clock_widget_expose(GtkWidget* widget, GdkEventExpose *event)
 {
@@ -1134,7 +1412,7 @@ desktop_clock_widget_expose(GtkWidget* widget, GdkEventExpose *event)
   gdk_cairo_region(cr, event->region);
   cairo_clip(cr);
   cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
-
+  _handle_orientation(cr, desktop_plugin);
   cairo_set_source_surface(cr, desktop_plugin->priv->background, 0, 0);
 
 
@@ -1229,10 +1507,10 @@ desktop_clock_widget_expose(GtkWidget* widget, GdkEventExpose *event)
 static void
 desktop_clock_widget_realize(GtkWidget* widget)
 {
+
   GdkScreen *screen = gtk_widget_get_screen(widget);
   gtk_widget_set_colormap(widget, gdk_screen_get_rgba_colormap(screen));
   gtk_widget_set_app_paintable(widget, TRUE);
-
   DesktopClockWidgetHomePlugin* desktop_plugin = DESKTOP_CLOCK_WIDGET_HOME_PLUGIN(widget);
   desktop_plugin->priv->iD = hd_home_plugin_item_get_applet_id (HD_HOME_PLUGIN_ITEM (widget));
   desktop_clock_widget_read_settings(desktop_plugin);
@@ -1240,6 +1518,8 @@ desktop_clock_widget_realize(GtkWidget* widget)
   {
     desktop_clock_widget_init_default_timezone(desktop_plugin);
   }
+  if(desktop_plugin->priv->autorotate)
+    _enable_listen_for_device_orientation(desktop_plugin);
   int height = desktop_plugin->priv->clock_height;
   if(desktop_plugin->priv->show_cityname)
     height += 16;
@@ -1277,7 +1557,8 @@ desktop_clock_widget_finalize(GObject* object)
     g_object_unref(desktop_plugin->priv->second_svg_handle);
   if(desktop_plugin->priv->second_shadow_svg_handle)
     g_object_unref(desktop_plugin->priv->second_shadow_svg_handle);
-
+  if(desktop_plugin->priv->autorotate)
+    _disable_listen_for_device_orientation(desktop_plugin);
   cityinfo_free(desktop_plugin->priv->city_info);
 
 
@@ -1310,6 +1591,8 @@ desktop_clock_widget_home_plugin_init(DesktopClockWidgetHomePlugin* desktop_plug
   desktop_plugin->priv->second_shadow_svg_handle = NULL;
   desktop_plugin->priv->city_info = NULL;
   desktop_plugin->priv->time_out_handler = 0;
+  desktop_plugin->priv->autorotate = FALSE;
+  desktop_plugin->priv->orientation_mode = 0;
   GtkWidget* contents = build_ui();
   hd_home_plugin_item_set_settings (HD_HOME_PLUGIN_ITEM (desktop_plugin), TRUE);
   g_signal_connect(desktop_plugin, "show-settings", G_CALLBACK(desktop_clock_widget_show_settings_dialog), NULL);
